jaclearn.math.rotation
======================

.. automodule:: jaclearn.math.rotation

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      as_rotation
      axisangle2quat
      euler2mat
      euler2point_euler
      euler2quat
      get_parallel_rotations
      mat2euler
      mat2quat
      normalize_angles
      point_euler2euler
      point_quat2quat
      quat2axisangle
      quat2euler
      quat2mat
      quat2point_quat
      quat_conjugate
      quat_identity
      quat_mul
      quat_rot_vec
      round_to_straight_angles
      subtract_euler
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: as_rotation

.. autofunction:: axisangle2quat

.. autofunction:: euler2mat

.. autofunction:: euler2point_euler

.. autofunction:: euler2quat

.. autofunction:: get_parallel_rotations

.. autofunction:: mat2euler

.. autofunction:: mat2quat

.. autofunction:: normalize_angles

.. autofunction:: point_euler2euler

.. autofunction:: point_quat2quat

.. autofunction:: quat2axisangle

.. autofunction:: quat2euler

.. autofunction:: quat2mat

.. autofunction:: quat2point_quat

.. autofunction:: quat_conjugate

.. autofunction:: quat_identity

.. autofunction:: quat_mul

.. autofunction:: quat_rot_vec

.. autofunction:: round_to_straight_angles

.. autofunction:: subtract_euler


